"""Rename BA & Utility service territory tables.

Revision ID: 00e4382815d9
Revises: c0841f4c5e4f
Create Date: 2024-04-08 15:51:41.934601

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '00e4382815d9'
down_revision = 'c0841f4c5e4f'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('out_eia861__yearly_balancing_authority_service_territory',
    sa.Column('county_id_fips', sa.Text(), nullable=False, comment='County ID from the Federal Information Processing Standard Publication 6-4.'),
    sa.Column('county_name_census', sa.Text(), nullable=True, comment='County name as specified in Census DP1 Data.'),
    sa.Column('population', sa.Float(), nullable=True, comment='County population, sourced from Census DP1 data.'),
    sa.Column('area_km2', sa.Float(), nullable=True, comment='County area in km2.'),
    sa.Column('report_date', sa.Date(), nullable=False, comment='Date reported.'),
    sa.Column('balancing_authority_id_eia', sa.Integer(), nullable=False, comment='EIA balancing authority ID. This is often (but not always!) the same as the utility ID associated with the same legal entity.'),
    sa.Column('state', sa.Text(), nullable=True, comment='Two letter US state abbreviation.'),
    sa.Column('county', sa.Text(), nullable=False, comment='County name.'),
    sa.Column('state_id_fips', sa.Text(), nullable=True, comment='Two digit state FIPS code.'),
    sa.PrimaryKeyConstraint('balancing_authority_id_eia', 'report_date', 'county_id_fips', 'county', name=op.f('pk_out_eia861__yearly_balancing_authority_service_territory'))
    )
    op.create_table('out_eia861__yearly_utility_service_territory',
    sa.Column('county_id_fips', sa.Text(), nullable=False, comment='County ID from the Federal Information Processing Standard Publication 6-4.'),
    sa.Column('county_name_census', sa.Text(), nullable=True, comment='County name as specified in Census DP1 Data.'),
    sa.Column('population', sa.Float(), nullable=True, comment='County population, sourced from Census DP1 data.'),
    sa.Column('area_km2', sa.Float(), nullable=True, comment='County area in km2.'),
    sa.Column('report_date', sa.Date(), nullable=False, comment='Date reported.'),
    sa.Column('utility_id_eia', sa.Integer(), nullable=False, comment='The EIA Utility Identification number.'),
    sa.Column('state', sa.Text(), nullable=True, comment='Two letter US state abbreviation.'),
    sa.Column('county', sa.Text(), nullable=True, comment='County name.'),
    sa.Column('state_id_fips', sa.Text(), nullable=True, comment='Two digit state FIPS code.'),
    sa.PrimaryKeyConstraint('utility_id_eia', 'report_date', 'county_id_fips', name=op.f('pk_out_eia861__yearly_utility_service_territory'))
    )
    op.drop_table('out_eia861__compiled_geometry_balancing_authorities')
    op.drop_table('out_eia861__compiled_geometry_utilities')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('out_eia861__compiled_geometry_utilities',
    sa.Column('county_id_fips', sa.TEXT(), nullable=False),
    sa.Column('county_name_census', sa.TEXT(), nullable=True),
    sa.Column('population', sa.FLOAT(), nullable=True),
    sa.Column('area_km2', sa.FLOAT(), nullable=True),
    sa.Column('report_date', sa.DATE(), nullable=False),
    sa.Column('utility_id_eia', sa.INTEGER(), nullable=False),
    sa.Column('state', sa.TEXT(), nullable=True),
    sa.Column('county', sa.TEXT(), nullable=True),
    sa.Column('state_id_fips', sa.TEXT(), nullable=True),
    sa.PrimaryKeyConstraint('utility_id_eia', 'report_date', 'county_id_fips', name='pk_out_eia861__compiled_geometry_utilities')
    )
    op.create_table('out_eia861__compiled_geometry_balancing_authorities',
    sa.Column('county_id_fips', sa.TEXT(), nullable=False),
    sa.Column('county_name_census', sa.TEXT(), nullable=True),
    sa.Column('population', sa.FLOAT(), nullable=True),
    sa.Column('area_km2', sa.FLOAT(), nullable=True),
    sa.Column('report_date', sa.DATE(), nullable=False),
    sa.Column('balancing_authority_id_eia', sa.INTEGER(), nullable=False),
    sa.Column('state', sa.TEXT(), nullable=True),
    sa.Column('county', sa.TEXT(), nullable=False),
    sa.Column('state_id_fips', sa.TEXT(), nullable=True),
    sa.PrimaryKeyConstraint('balancing_authority_id_eia', 'report_date', 'county_id_fips', 'county', name='pk_out_eia861__compiled_geometry_balancing_authorities')
    )
    op.drop_table('out_eia861__yearly_utility_service_territory')
    op.drop_table('out_eia861__yearly_balancing_authority_service_territory')
    # ### end Alembic commands ###
