"""Add my cool NREL ATB tables

Revision ID: e0d3904b97f4
Revises: 172898b30824
Create Date: 2024-04-26 09:59:29.741088

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e0d3904b97f4'
down_revision = '172898b30824'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('core_nrelatb__yearly_projected_cost_performance',
    sa.Column('report_year', sa.Integer(), nullable=True, comment='Four-digit year in which the data was reported.'),
    sa.Column('model_case_nrelatb', sa.Enum('Market', 'R&D'), nullable=True, comment="NREL's financial assumption cases. There are two cases which effect project finanical assumptions: R&D Only Case and Market + Policies Case. R&D Only includes only projected R&D improvements while Market + Policy case includes policy and tax incentives. https://atb.nrel.gov/electricity/2023/financial_cases_&_methods"),
    sa.Column('projection_year', sa.Integer(), nullable=True, comment='The year of the projected value.'),
    sa.Column('technology_description', sa.Enum('CSP', 'Biopower', 'OffShoreWind', 'Pumped Storage Hydropower', 'Nuclear', 'Commercial Battery Storage', 'Coal_FE', 'ResPV', 'Coal_Retrofits', 'UtilityPV', 'Utility-Scale Battery Storage', 'NaturalGas_FE', 'NaturalGas_Retrofits', 'CommPV', 'Residential Battery Storage', 'DistributedWind', 'LandbasedWind', 'Utility-Scale PV-Plus-Battery', 'Geothermal', 'Hydropower', 'AEO'), nullable=True, comment='High level description of the technology used by the generator to produce electricity.'),
    sa.Column('cost_recovery_period_years', sa.Integer(), nullable=True, comment='The period over which the initial capital investment to build a plant is recovered.'),
    sa.Column('scenario_atb', sa.Enum('Advanced', 'Moderate', 'Conservative'), nullable=True, comment='Technology innovation scenarios. https://atb.nrel.gov/electricity/2023/definitions#scenarios'),
    sa.Column('technology_description_detail_1', sa.Text(), nullable=True, comment='Technology details indicate resource levels and specific technology subcategories.'),
    sa.Column('technology_description_detail_2', sa.Text(), nullable=True, comment='Technology details indicate resource levels and specific technology subcategories.'),
    sa.Column('capacity_factor', sa.Float(), nullable=True, comment='Fraction of potential generation that was actually reported for a plant part.'),
    sa.Column('capex_per_kw', sa.Float(), nullable=True, comment='Capital cost (USD). Expenditures required to achieve commercial operation of the generation plant.'),
    sa.Column('capex_overnight_per_kw', sa.Float(), nullable=True, comment='capex if plant could be constructed overnight (i.e., excludes construction period financing); includes on-site electrical equipment (e.g., switchyard), a nominal-distance spur line (<1 mi), and necessary upgrades at a transmission substation.'),
    sa.Column('capex_overnight_additional_per_kw', sa.Float(), nullable=True, comment='capex for retrofits if plant could be constructed overnight (i.e., excludes construction period financing); includes on-site electrical equipment (e.g., switchyard), a nominal-distance spur line (<1 mi), and necessary upgrades at a transmission substation.'),
    sa.Column('capex_grid_connection_per_kw', sa.Float(), nullable=True, comment='Overnight capital cost includes a nominal-distance spur line (<1 mi) for all technologies, and for offshore wind, it includes export cable and construction period transit costs for a 30-km distance from shore. Project-specific costs lines that are based on distance to existing transmission are not included.'),
    sa.Column('capex_construction_finance_factor', sa.Float(), nullable=True, comment='Portion of all-in capital cost associated with construction period financing. This factor is applied to an overnight capital cost to represent the financing costs incurred during the construction period.'),
    sa.Column('heat_rate_mmbtu_per_mwh', sa.Float(), nullable=True, comment='Fuel content per unit of electricity generated.'),
    sa.Column('heat_rate_penalty', sa.Float(), nullable=True, comment='Heat rate penalty for retrofitting. This column only has contents to retrofit technologies. It seems to be a rate between 0.35 and 0.09'),
    sa.Column('levelized_cost_of_energy_per_mwh', sa.Float(), nullable=True, comment='Levelized cost of energy (LCOE) is a summary metric that combines the primary technology cost and performance parameters: capital expenditures, operations expenditures, and capacity factor.'),
    sa.Column('net_output_penalty', sa.Float(), nullable=True, comment='Penalty for retrofitting for net output.  This column only has contents to retrofit technologies. It seems to be a rate between -0.25 and -0.08'),
    sa.Column('opex_fixed_per_kw', sa.Float(), nullable=True, comment='Fixed operation and maintenance expenses. Annual expenditures to operate and maintain equipment that are not incurred on a per-unit-energy basis.'),
    sa.Column('opex_variable_per_mwh', sa.Float(), nullable=True, comment='Operation and maintenance costs incurred on a per-unit-energy basis.')
    )
    op.create_table('core_nrelatb__yearly_projected_financial_cases',
    sa.Column('report_year', sa.Integer(), nullable=False, comment='Four-digit year in which the data was reported.'),
    sa.Column('model_case_nrelatb', sa.Enum('Market', 'R&D'), nullable=False, comment="NREL's financial assumption cases. There are two cases which effect project finanical assumptions: R&D Only Case and Market + Policies Case. R&D Only includes only projected R&D improvements while Market + Policy case includes policy and tax incentives. https://atb.nrel.gov/electricity/2023/financial_cases_&_methods"),
    sa.Column('projection_year', sa.Integer(), nullable=False, comment='The year of the projected value.'),
    sa.Column('technology_description', sa.Enum('CSP', 'Biopower', 'OffShoreWind', 'Pumped Storage Hydropower', 'Nuclear', 'Commercial Battery Storage', 'Coal_FE', 'ResPV', 'Coal_Retrofits', 'UtilityPV', 'Utility-Scale Battery Storage', 'NaturalGas_FE', 'NaturalGas_Retrofits', 'CommPV', 'Residential Battery Storage', 'DistributedWind', 'LandbasedWind', 'Utility-Scale PV-Plus-Battery', 'Geothermal', 'Hydropower', 'AEO'), nullable=False, comment='High level description of the technology used by the generator to produce electricity.'),
    sa.Column('inflation_rate', sa.Float(), nullable=True, comment='Rate of inflation. All dollar values are given in 2021 USD, using the Consumer Price Index for All Urban Consumers for dollar year conversions where the source year dollars do not match 2021.'),
    sa.Column('interest_rate_during_construction_nominal', sa.Float(), nullable=True, comment='Also referred to as construction finance cost. Portion of all-in capital cost associated with construction period financing. It is a function of construction duration, capital fraction during construction, and interest during construction.'),
    sa.Column('interest_rate_calculated_real', sa.Float(), nullable=True, comment='Calculated real interest rate.'),
    sa.Column('interest_rate_nominal', sa.Float(), nullable=True, comment='Nominal interest rate.'),
    sa.Column('rate_of_return_on_equity_calculated_real', sa.Float(), nullable=True, comment='Calculated real rate of return on equity.'),
    sa.Column('rate_of_return_on_equity_nominal', sa.Float(), nullable=True, comment='Nomial rate of return on equity.'),
    sa.Column('tax_rate_federal_state', sa.Float(), nullable=True, comment='Combined federal and state tax rate. The R&D model_case_nrelatb holds tax and inflation rates constant at assumed long-term values: 21 percent federal tax rate, 6 percent state tax rate (though actual state tax rates vary), and 2.5 percent inflation rate excludes effects of tax credits. The Market + Policy model_case_nrelatb applies federal tax credits and expires them as consistent with existing law and guidelines.'),
    sa.PrimaryKeyConstraint('report_year', 'model_case_nrelatb', 'projection_year', 'technology_description', name=op.f('pk_core_nrelatb__yearly_projected_financial_cases'))
    )
    op.create_table('core_nrelatb__yearly_projected_financial_cases_by_scenario',
    sa.Column('report_year', sa.Integer(), nullable=True, comment='Four-digit year in which the data was reported.'),
    sa.Column('model_case_nrelatb', sa.Enum('Market', 'R&D'), nullable=True, comment="NREL's financial assumption cases. There are two cases which effect project finanical assumptions: R&D Only Case and Market + Policies Case. R&D Only includes only projected R&D improvements while Market + Policy case includes policy and tax incentives. https://atb.nrel.gov/electricity/2023/financial_cases_&_methods"),
    sa.Column('projection_year', sa.Integer(), nullable=True, comment='The year of the projected value.'),
    sa.Column('technology_description', sa.Enum('CSP', 'Biopower', 'OffShoreWind', 'Pumped Storage Hydropower', 'Nuclear', 'Commercial Battery Storage', 'Coal_FE', 'ResPV', 'Coal_Retrofits', 'UtilityPV', 'Utility-Scale Battery Storage', 'NaturalGas_FE', 'NaturalGas_Retrofits', 'CommPV', 'Residential Battery Storage', 'DistributedWind', 'LandbasedWind', 'Utility-Scale PV-Plus-Battery', 'Geothermal', 'Hydropower', 'AEO'), nullable=True, comment='High level description of the technology used by the generator to produce electricity.'),
    sa.Column('scenario_atb', sa.Enum('Advanced', 'Moderate', 'Conservative'), nullable=True, comment='Technology innovation scenarios. https://atb.nrel.gov/electricity/2023/definitions#scenarios'),
    sa.Column('cost_recovery_period_years', sa.Integer(), nullable=True, comment='The period over which the initial capital investment to build a plant is recovered.'),
    sa.Column('capital_recovery_factor', sa.Float(), nullable=True, comment='Ratio of a constant annuity to the present value of receiving that annuity for a given length of time.'),
    sa.Column('debt_fraction', sa.Float(), nullable=True, comment='Fraction of capital financed with debt; Debt fraction is assumed financed with equity; also referred to as the leverage ratio.'),
    sa.Column('fixed_charge_rate', sa.Float(), nullable=True, comment='Amount of revenue per dollar of investment required that must be collected annually from customers to pay the carrying charges on that investment.'),
    sa.Column('fuel_cost', sa.Float(), nullable=True, comment='Total fuel cost for plant (in $USD).'),
    sa.Column('wacc_nominal', sa.Float(), nullable=True, comment='Nominal weighted average cost of capital - average expected rate that is paid to finance assets.'),
    sa.Column('wacc_real', sa.Float(), nullable=True, comment='Real weighted average cost of capital - average expected rate that is paid to finance assets.')
    )
    op.create_table('core_nrelatb__yearly_technology_status',
    sa.Column('report_year', sa.Integer(), nullable=True, comment='Four-digit year in which the data was reported.'),
    sa.Column('technology_description', sa.Enum('CSP', 'Biopower', 'OffShoreWind', 'Pumped Storage Hydropower', 'Nuclear', 'Commercial Battery Storage', 'Coal_FE', 'ResPV', 'Coal_Retrofits', 'UtilityPV', 'Utility-Scale Battery Storage', 'NaturalGas_FE', 'NaturalGas_Retrofits', 'CommPV', 'Residential Battery Storage', 'DistributedWind', 'LandbasedWind', 'Utility-Scale PV-Plus-Battery', 'Geothermal', 'Hydropower', 'AEO'), nullable=True, comment='High level description of the technology used by the generator to produce electricity.'),
    sa.Column('technology_description_detail_1', sa.Text(), nullable=True, comment='Technology details indicate resource levels and specific technology subcategories.'),
    sa.Column('technology_description_detail_2', sa.Text(), nullable=True, comment='Technology details indicate resource levels and specific technology subcategories.'),
    sa.Column('is_technology_mature', sa.Boolean(), nullable=True, comment='Indicator of whether the technology is mature.'),
    sa.Column('is_default', sa.Boolean(), nullable=True, comment='Indicator of whether the technology is default.')
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('core_nrelatb__yearly_technology_status')
    op.drop_table('core_nrelatb__yearly_projected_financial_cases_by_scenario')
    op.drop_table('core_nrelatb__yearly_projected_financial_cases')
    op.drop_table('core_nrelatb__yearly_projected_cost_performance')
    # ### end Alembic commands ###
